#!/bin/sh
# Copyright 2011 Paul Hänsch
# This file is part of Stereofy
#
# Stereofy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Stereofy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Stereofy.  If not, see <http://www.gnu.org/licenses/>.

algo="d"   #algorythm, Dubois by default
model="rc" #color model, red-cyan by default
param=""   #leave blank, will be -$algo$model
left=''
right=''
stereo=''

while [ -n "$1" ]; do
  case "$1" in
    -d|--dubois) algo="d";;
    -f|--full|--full-color) algo="f";;
    -h|--half|--half-color) algo="d";;
    -rc|--rc|--red-cyan) model="rc";;
    -mc|--mc|--magenta-cyan) model="mc";;
    -gm|--gm|--green-magenta) model="gm";;
    -ab|--ab|--amber-blue|--yellow-blue) model="ab";;
    -[dfh]rc|-[dfh]gm|-[fe]mc|-dab) param="$1";;
    -*) echo "no such color model" >/dev/stderr; exit 1;;
    *)  if [ -z "$left" ]; then
	  left="$1"
	elif [ -z "$right" ]; then
	  right="$1"
	elif [ -z "$stereo" ]; then
	  stereo="$1"
	fi
	;;
  esac
  shift 1;
done

[ -z "$param" ] && param="-$algo$model"
[ -z "$stereo" ] && stereo="${left}_stereo.jpg"

echo -n preparing...
geom=$(identify "$left" |sed -rn 's:^.* ([0-9]+x[0-9]+) .*$:\1:gp')
tmp=$(tempfile -d /tmp -p strfy)
rm "$tmp"
mkfifo "$tmp"

convert "$left" rgb:- >"$tmp" &
echo -n anaglyphing...
convert "$right" rgb:- |anaglyph "$param" "$tmp" /dev/stdin /dev/stdout |convert -depth 8 -size "$geom" rgb:- "$stereo"

echo cleaning...
rm "$tmp"
